const { promisify } = require('util');
const download = promisify(require('download-git-repo'));
const { vueRepo } = require('../config/repo-config');
const { commandSpanw } = require('../utils/terminal');
const open = require('open');
const { start } = require('repl');
const fs = require('fs');
const path = require('path');

const createProjectAction = async (projectName) => {
  console.log('zwt helps you create a new project');
  //1. clone 模版到本地
  await download(vueRepo, projectName, { clone: true });
  //2. 执行 npm install
  const command = process.platform == 'win32' ? 'npm.cmd' : 'npm';  //根据不同平台执行不同命令
  await commandSpanw(command, ['install'], { cwd: `./${projectName}` });
  //3. 执行 npm run serve
  commandSpanw(command, ['run', 'serve'], { cwd: `./${projectName}` });
  //4. 打开浏览器
  open('http://localhost:8080/');
};

const openWebsiteAction = (website = 'https://music.163.com') => {
  console.log(`opening the website: ${website}`);

  open(website);
}

const changeDirAction = (startPath, endPath, extension) => {
  console.log('helping you to move files');
  // 1. 从配置文件中读取路径名，扩展名等参数
  const config = require('../config/moveDir-config.json');
  const startPathDefault = config.startPath;
  const endPathDefault = config.endPath;
  const extensionDefault = config.extension;

  startPath = (startPath == undefined) ? startPathDefault : startPath;
  endPath = (endPath == undefined) ? endPathDefault : endPath;
  extension = (extension == undefined) ? extensionDefault : extension;
  extension = extension.split(' ');
  // 2. 读取起始目录下的所有内容
  fs.readdirSync(startPath).forEach( (file) => {
    const pathName = path.join(startPath, file);  // 拼接路径
    const fsStat = fs.statSync(pathName); // 读取文件状态

    // 判断是否为文件夹,若为文件夹则跳过或做其他特殊处理
    if(!fsStat.isDirectory()) {
      const fileExtension = path.extname(file);
      const state = extension.some(f => {
        return f === fileExtension;
      });

      if (state) {
        // 将文件转移
        fs.writeFileSync(path.join(endPath, file), fs.readFileSync(pathName));
        // 将起始路径下的文件删除
        fs.unlinkSync(pathName);
      }
    }

  });
}

module.exports = {
  createProjectAction,
  openWebsiteAction,
  changeDirAction
}